package io.nisum.spark.producer;

import org.apache.spark.sql.Dataset;
import org.apache.spark.sql.Row;
import org.apache.spark.sql.SparkSession;
import org.apache.spark.sql.functions;

import java.util.HashMap;
import java.util.Map;

public class SparkKafkaProducer {
    public static void main(String[] args) {
        try {
            SparkSession spark = SparkSession.builder()
                    .master("local[*]")
                    .appName("Produce Product Info to Kafka Topic")
                    .getOrCreate();

            Dataset<Row> productInfoDf = spark.read()
                    .format("json")
                    .option("header", true )
                    .option("multiline", "true")
                    .load("src/data/product-info.json");

            productInfoDf.printSchema();

            Map<String, String> kafkaConfigMap = new HashMap<String, String>();
            kafkaConfigMap.put("kafka.bootstrap.servers", "127.0.0.1:9092");
            kafkaConfigMap.put("topic", "product-info-topic4");

            productInfoDf
                    .select(
                            functions.to_json(
                                    functions.struct(
                                            productInfoDf.col("deliveryStatus"),
                                            productInfoDf.col("productId"),
                                            productInfoDf.col("productName"),
                                            productInfoDf.col("productPrice"),
                                            productInfoDf.col("date")
                                    )
                            )
                                    .alias("value")
                    ).write()
                    .options(kafkaConfigMap)
                    .format("kafka")
                    .save();

        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
